@@ -19,7 +19,7 @@ HTML::FormatText::WithLinks::AndTables - Converts HTML to Text with tables intac
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =cut
 
@@ -286,7 +286,7 @@ Given the HTML below ...
 
 =head1 CAVEATS
 
-    * This does not handle <TH> elements whatsoever!
+    * <TH> elements are treated identically to <TD> elements
 
     * It assumes a fixed width font for display of resulting text.
 
